# vtds-platform-ubuntu

An Ubuntu Linux Virtual Blade based vTDS Platform Layer Implementation.

## Description

This Platform Layer Implementation provides the code and
[base configuration](https://github.com/Cray-HPE/vtds-platform-ubuntu/blob/main/vtds_platform_ubuntu/private/config/config.yaml)
to configure a set of Ubuntu Linux based Virtual Blades for use under
vTDS. For more information about configuring this Layer Implementation
see the annotated base configuration linked above.

A brief introduction to vTDS can be found in the [vTDS Core Project
Repository](https://github.com/Cray-HPE/vtds-core/blob/main/README.md).
